@@ -1,3 +1,3 @@
 from datatorch.api import ApiClient
 
-__all__ = ['ApiClient']
+__all__ = ["ApiClient"]
